# Game Of Life

This program is build to demonstrate Conway's game of life. <br/><br/>
The game has several specific rules that cells obey. The color of the cell is depended on these rules.
The rules specify how many alive or dead neighbors a cell can have to stay alive, die or give birth. <br/><br/>
Although the rules in Conway's game of life are very specific, this program will give the user the option to experiment
with these rules. The default rules in the program are based on Conway's Game of Life. <br/><br/>

Changing the rules will give a radical change to way the cells interact, this program can be used to demonstrate the
balance and see what happens if it gets disrupted.<br/><br/>

The game can be installed in the terminal/shell using: pip install pygol <br/>
To start the game use: pygol.rungame() <br/>
To close the game use the close button in the game <br/><br/>



